AuthResource class

Authentication: API keys, access tokens, OAuth providers.

Inheritance

Constructors

AuthResource(Transport transport)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transport Transport
finalinherited

Methods

authenticate({Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /auth
authenticate2({required Object provider, Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /auth/{provider}
authenticate3({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /v3/auth
authenticate4({required Object provider, Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /v3/auth/{provider}
getAccessToken({Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /access-token
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited