menu
norbix package
documentation
norbix_hub.dart
EchoResource class
EchoResource class
dark_mode
light_mode
EchoResource
class
Health-check / echo endpoint.
Inheritance
Object
Resource
EchoResource
Constructors
EchoResource
(
Transport
transport
)
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
transport
→
Transport
final
inherited
Methods
echo
(
{
Map
<
String
,
Object
?
>
?
query
,
Map
<
String
,
String
>
?
headers
})
→
Future
<
Object
?
>
GET /{version}/echo
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
norbix package
documentation
norbix_hub
EchoResource class
norbix_hub library