EmailUnsubscribeResource class

RFC-8058 one-click unsubscribe endpoint.

Inheritance

Constructors

EmailUnsubscribeResource(Transport transport)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transport Transport
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
oneClickUnsubscribe({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /{version}/email/one-click-unsubscribe
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited