HttpDriver class abstract

Pluggable HTTP driver. Default is the standard package:http client. Tests inject MockClient; Flutter apps can swap in dio or a custom pinned-cert client by implementing this interface.

Implementers

Constructors

HttpDriver()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(HttpDriverRequest request) Future<HttpDriverResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited