HttpDriverRequest class

Constructors

HttpDriverRequest({required String method, required Uri url, required Map<String, String> headers, String? body, Duration timeout = const Duration(seconds: 30)})
const

Properties

body String?
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
method String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
final
url Uri
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited