menu
norbix package
documentation
norbix_hub.dart
HttpDriverResponse class
HttpDriverResponse class
dark_mode
light_mode
HttpDriverResponse
class
Constructors
HttpDriverResponse
({
required
int
statusCode
,
required
Map
<
String
,
String
>
headers
,
required
String
body
,
List
<
int
>
?
bytes
})
const
Properties
body
→
String
final
bytes
→
List
<
int
>
?
Raw response body. Set by drivers that can supply it; when a driver leaves it null the transport falls back to the UTF-8 bytes of
body
. Only the file-download calls read it — everything else parses
body
.
final
hashCode
→
int
The hash code for this object.
no setter
inherited
headers
→
Map
<
String
,
String
>
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
statusCode
→
int
final
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
norbix package
documentation
norbix_hub
HttpDriverResponse class
norbix_hub library