InternalsResource class

Internal Norbix utilities (typegen, debug).

Inheritance

Constructors

InternalsResource(Transport transport)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transport Transport
finalinherited

Methods

internalsTypeGen({Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /internal/_typegen
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited