LogsResource class

Logging integrations.

Inheritance

Constructors

LogsResource(Transport transport)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transport Transport
finalinherited

Methods

deleteLoggingIntegration({required Object id, Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
DELETE /{version}/logs/integrations/{id}
disableLogging({Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/logs/disable
disableLoggingIntegration({required Object id, Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
PUT /{version}/logs/integrations/{id}/disable
enableLogging({Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/logs/enable
enableLoggingIntegration({required Object id, Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
PUT /{version}/logs/integrations/{id}/enable
getLoggingIntegration({required Object id, Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/logs/integrations/{id}
getLoggingIntegrations({Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/logs/integrations
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveLoggingIntegration({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /{version}/logs/integrations
testLoggingIntegration({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /{version}/logs/integrations/test
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited