UserNotificationPreferencesResource class

Per-user notification opt-ins.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transport Transport
finalinherited

Methods

getUserNotificationPreferences({Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/user/preferences
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateUserNotificationsPreferences({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
PUT /{version}/notifications/user/preferences

Operators

operator ==(Object other) bool
The equality operator.
inherited