WebhooksResource class

Outbound webhook destinations and integration settings.

Inheritance

Constructors

WebhooksResource(Transport transport)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transport Transport
finalinherited

Methods

disableWebhookDestination({required Object destinationId, Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
PUT /{version}/webhooks/destinations/{destinationId}/disable
enableWebhookDestination({required Object destinationId, Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
PUT /{version}/webhooks/destinations/{destinationId}/enable
getWebhookIntegration({Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/webhooks/integration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeWebhookDestination({required Object destinationId, Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
DELETE /{version}/webhooks/destinations/{destinationId}
revealWebhookIntegrationSecret({Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/webhooks/integration/secret
rotateWebhookIntegrationSecret({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /{version}/webhooks/integration/secret/rotate
saveWebhookDestination({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /{version}/webhooks/destinations
toString() String
A string representation of this object.
inherited
updateWebhookIntegrationExtraHeaders({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
PUT /{version}/webhooks/integration/extra-headers

Operators

operator ==(Object other) bool
The equality operator.
inherited