FileResourceRef class

A file reference carried by files.file.uploaded.

Constructors

FileResourceRef({String? path, String? name, int? size, String? contentType, Map<String, dynamic> raw = const {}})
const
FileResourceRef.fromJson(Map<String, dynamic> json)
factory

Properties

contentType → String?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
path → String?
final
raw → Map<String, dynamic>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited