Named event constants — use these instead of raw strings.
receiver.on(NorbixWebhookEvents.membershipUserRegistered, (user, event) {});
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- databaseRecordDeleted → const String
- databaseRecordInserted → const String
- databaseRecordReplaced → const String
- databaseRecordResponsibilityChanged → const String
- databaseRecordsDeleted → const String
- databaseRecordsInserted → const String
- databaseRecordsUpdated → const String
- databaseRecordUpdated → const String
- filesFileDeleted → const String
- filesFileUploaded → const String
- membershipUserBlocked → const String
- membershipUserDeleted → const String
- membershipUserInvited → const String
- membershipUserReactivated → const String
- membershipUserRegistered → const String
- membershipUserUpdated → const String
- membershipUserVerified → const String