Normalized class

The payload + metadata produced from a raw envelope.

Constructors

Normalized(dynamic payload, WebhookEventMetadata metadata)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
metadata WebhookEventMetadata
final
payload → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited