UserInvited class

membership.user.invited payload (no full entity yet).

Constructors

UserInvited({String? email})
const
UserInvited.fromJson(Map<String, dynamic> json)
factory

Properties

email String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited