WebhookEnvelope class

The raw JSON envelope POSTed to a destination.

Constructors

WebhookEnvelope({required String id, required String event, String? createdOn, String? accountId, String? projectId, String? triggerId, dynamic data})
const
WebhookEnvelope.fromJson(Map<String, dynamic> json)
factory

Properties

accountId → String?
final
createdOn → String?
final
data → dynamic
final
event → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
projectId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggerId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited