WebhookEvent class

Metadata object passed as the 2nd argument to a typed handler.

Constructors

WebhookEvent({required String name, required String deliveryId, String? createdOn, String? triggerId, String? correlationId, String? accountId, String? projectId, String? integrationId, String? destinationId, bool? verified, required WebhookEventMetadata metadata, required WebhookEnvelope raw})
const

Properties

accountId → String?
final
correlationId → String?
final
createdOn → String?
final
deliveryId → String
final
destinationId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
integrationId → String?
final
metadata → WebhookEventMetadata
final
name → String
final
projectId → String?
final
raw → WebhookEnvelope
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggerId → String?
final
verified → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited