PushNotificationsResource class

Push templates, integrations, devices.

Inheritance

Constructors

PushNotificationsResource(Transport transport)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transport Transport
finalinherited

Methods

archivePushTemplate({required Object id, Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
PUT /{version}/notifications/push/templates/{id}/archive
checkIntegrationAvailability({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /{version}/notifications/push/integrations/app/check
clonePushTemplate({required Object id, Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /{version}/notifications/push/templates/{id}/clone
confirmPushIntegrationHumanDelivery({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /{version}/notifications/push/integrations/confirm-human-delivery
createPushCampaign({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /{version}/notifications/push/campaigns
createPushTemplate({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /{version}/notifications/push/templates
deletePushCampaign({required Object id, Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
DELETE /{version}/notifications/push/campaigns/{id}
deletePushIntegration({required Object id, Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
DELETE /{version}/notifications/push/integrations/{id}
deletePushTemplate({required Object id, Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
DELETE /{version}/notifications/push/templates/{id}
disablePush({Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/push/disable
disablePushIntegration({required Object id, Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
PUT /{version}/notifications/push/integrations/{id}/disable
enablePush({Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/push/enable
enablePushIntegration({required Object id, Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
PUT /{version}/notifications/push/integrations/{id}/enable
getPushCampaign({required Object id, Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/push/campaigns/{id}
getPushCampaignBatches({required Object id, Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/push/campaigns/{id}/batches
getPushCampaignBatchNotification({required Object id, required Object batchId, required Object notificationId, Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/push/campaigns/{id}/batches/{batchId}/{notificationId}
getPushCampaignBatchNotifications({required Object id, required Object batchId, Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/push/campaigns/{id}/batches/{batchId}
getPushCampaignMessage({required Object campaignId, required Object id, Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/push/campaigns/{campaignId}/messages/{id}
getPushCampaignMessages({required Object campaignId, Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/push/campaigns/{campaignId}/messages
getPushCampaigns({Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/push/campaigns
getPushCampaignStatistics({required Object id, Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/push/campaigns/{id}/stats
getPushIntegration({required Object id, Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/push/integrations/{id}
getPushIntegrations({Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/push/integrations
getPushMessageContentTokens({required Object id, Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/push/templates/{id}/tokens
getPushSettings({Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/push/settings
getPushTemplate({required Object id, Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/push/templates/{id}
getPushTemplates({Map<String, Object?>? query, Map<String, String>? headers}) Future<Object?>
GET /{version}/notifications/push/templates
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerCodeMashAppPushIntegration({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /{version}/notifications/push/integrations/app/request
registerDevice({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /{version}/notifications/push/devices
savePushIntegration({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /{version}/notifications/push/integrations
setPushIntegrationAsDefault({required Object id, Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
PUT /{version}/notifications/push/integrations/{id}/default
testCodeMashIosAppIntegration({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /{version}/notifications/push/integrations/test/codemash-app
testPushIntegration({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
POST /{version}/notifications/push/integrations/test
toString() String
A string representation of this object.
inherited
unArchivePushTemplate({required Object id, Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
PUT /{version}/notifications/push/templates/{id}/unarchive
updatePushTemplate({Map<String, Object?>? query, Object? body, Map<String, String>? headers}) Future<Object?>
PUT /{version}/notifications/push/templates

Operators

operator ==(Object other) bool
The equality operator.
inherited