DeliveryHeaders class

Parsed Norbix delivery headers from an inbound request.

Constructors

DeliveryHeaders({String? event, String? deliveryId, String? idempotencyKey, String? accountId, String? projectId, String? integrationId, String? destinationId, String? signature, String? timestamp})
const

Properties

accountId String?
final
deliveryId String?
final
destinationId String?
final
event String?
final
hashCode int
The hash code for this object.
no setterinherited
idempotencyKey String?
final
integrationId String?
final
projectId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String?
final
timestamp String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited