UserDto class
A membership user. Email / username are optional (username-only signup).
Constructors
Properties
- createdOn → String?
-
final
- email → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- modifiedOn → String?
-
final
-
raw
→ Map<
String, dynamic> -
Unmapped fields, preserved from the wire payload.
final
-
roles
→ List<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String?
-
final
-
final
- type → String?
-
final
- userName → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited