WebhookContext class
Context passed to onAll handlers alongside the envelope.
Constructors
Properties
- accountId → String?
-
final
- destinationId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- integrationId → String?
-
final
- path → String?
-
final
- projectId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verified → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited