WebhookEventMetadata class

Identifiers lifted off the wire payload onto WebhookEvent.metadata.

Constructors

WebhookEventMetadata({WebhookEntityRef? user, WebhookSchemaInfo? schema, WebhookEntityRef? record, WebhookRecordIds? records, String? integrationId})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
integrationId String?
final
record WebhookEntityRef?
final
records WebhookRecordIds?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema WebhookSchemaInfo?
final
user WebhookEntityRef?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited