WebhookHandleResult class

Result of handling a delivery (respond 200 to the caller).

Constructors

WebhookHandleResult({bool received = true, required String event, required String deliveryId, bool? verified, bool handled = false, String? triggerId})
const

Properties

deliveryId String
final
event String
final
handled bool
final
hashCode int
The hash code for this object.
no setterinherited
received bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
triggerId String?
final
verified bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited